@@ -1,5 +1,8 @@
 from abc import ABC, abstractmethod
 import multiprocessing
+from typing import Dict, List
+from FreeTAKServer.model.ClientInformation import ClientInformation
+from FreeTAKServer.model.SQLAlchemy.User import User
 
 class ServiceInterface(ABC):
 
@@ -12,7 +15,7 @@ class ServiceInterface(ABC):
         raise NotImplementedError
 
 class ServerServiceInterface(ServiceInterface):
-    from FreeTAKServer.controllers.configuration.Types import Types
+    from FreeTAKServer.controllers.configuration.types import Types
     @abstractmethod
     def send_data_to_clients(self, data: Types.fts_object):
         raise NotImplementedError
@@ -23,6 +26,15 @@ class ServerServiceInterface(ServiceInterface):
 
 class ServiceBase(ServiceInterface):
 
+    @abstractmethod
+    def get_service_users(self) -> List[User]:
+        """ the implementation of this method
+
+        Returns Dict[str, ClientInformation]: a dictionary of client uid's and their associated objects
+
+        """
+        raise NotImplementedError
+
     def receive_command_data(self, pipe: multiprocessing.Pipe) -> any:
         if not pipe.empty():
             return pipe.get()
@@ -30,4 +42,4 @@ class ServiceBase(ServiceInterface):
             return None
 
     def define_responsibility_chain(self):
-        pass
\ No newline at end of file
+        raise NotImplementedError
\ No newline at end of file
